# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`skopeo`](#skopeo): skopeo image synchronization

#### Private Classes

* `skopeo::config`: Manage common configuration
* `skopeo::install`: Manage skopeo binary installation

### Defined types

* [`skopeo::sync`](#skopeo--sync): Manage configuration for scopeo sync

### Data types

* [`Skopeo::Args`](#Skopeo--Args): Optional arguments
* [`Skopeo::ByTag`](#Skopeo--ByTag): Images with tag/version specification
* [`Skopeo::DestType`](#Skopeo--DestType): Source transport type
* [`Skopeo::Matrix`](#Skopeo--Matrix): Configuration images X versions to sync
* [`Skopeo::SrcType`](#Skopeo--SrcType): Source transport type
* [`Skopeo::SyncType`](#Skopeo--SyncType): Configuration of synchronization targets

## Classes

### <a name="skopeo"></a>`skopeo`

skopeo image synchronization

#### Parameters

The following parameters are available in the `skopeo` class:

* [`user`](#-skopeo--user)
* [`group`](#-skopeo--group)
* [`manage_package`](#-skopeo--manage_package)
* [`manage_user`](#-skopeo--manage_user)
* [`manage_group`](#-skopeo--manage_group)
* [`package_ensure`](#-skopeo--package_ensure)
* [`uid`](#-skopeo--uid)
* [`base_dir`](#-skopeo--base_dir)
* [`log_dir`](#-skopeo--log_dir)
* [`sync`](#-skopeo--sync)
* [`args`](#-skopeo--args)

##### <a name="-skopeo--user"></a>`user`

Data type: `String`

User account used for command execution

##### <a name="-skopeo--group"></a>`group`

Data type: `String`



##### <a name="-skopeo--manage_package"></a>`manage_package`

Data type: `Boolean`

Whether package should be installed by this module

##### <a name="-skopeo--manage_user"></a>`manage_user`

Data type: `Boolean`

Whether user should be managed by this module

##### <a name="-skopeo--manage_group"></a>`manage_group`

Data type: `Boolean`

Whether group should be managed by this module

##### <a name="-skopeo--package_ensure"></a>`package_ensure`

Data type: `String`

`present`, `absent` or specific package version

##### <a name="-skopeo--uid"></a>`uid`

Data type: `Optional[Integer]`

user id

Default value: `undef`

##### <a name="-skopeo--base_dir"></a>`base_dir`

Data type: `Stdlib::Unixpath`

Work dir (home dir) for scopeo configs

##### <a name="-skopeo--log_dir"></a>`log_dir`

Data type: `Stdlib::Unixpath`

Directory for storing logs

##### <a name="-skopeo--sync"></a>`sync`

Data type: `Skopeo::SyncType`

Synchronization config, see examples

Default value: `{}`

##### <a name="-skopeo--args"></a>`args`

Data type: `Skopeo::Args`

Optional arguments as Hash

Default value: `{}`

## Defined types

### <a name="skopeo--sync"></a>`skopeo::sync`

Sync copies Docker/OCI images from source to destination registry

#### Examples

##### 

```puppet
skopeo::sync { 'registry':
  src  => 'index.docker.io',
  dest => 'my.registry',
}
```

#### Parameters

The following parameters are available in the `skopeo::sync` defined type:

* [`src`](#-skopeo--sync--src)
* [`src_type`](#-skopeo--sync--src_type)
* [`dest`](#-skopeo--sync--dest)
* [`dest_prefix`](#-skopeo--sync--dest_prefix)
* [`dest_type`](#-skopeo--sync--dest_type)
* [`args`](#-skopeo--sync--args)
* [`matrix`](#-skopeo--sync--matrix)
* [`by_tag`](#-skopeo--sync--by_tag)
* [`tls_verify`](#-skopeo--sync--tls_verify)
* [`redirect_logs`](#-skopeo--sync--redirect_logs)
* [`on_change`](#-skopeo--sync--on_change)
* [`user`](#-skopeo--sync--user)
* [`group`](#-skopeo--sync--group)
* [`base_dir`](#-skopeo--sync--base_dir)
* [`log_dir`](#-skopeo--sync--log_dir)

##### <a name="-skopeo--sync--src"></a>`src`

Data type: `String`

Source registry

##### <a name="-skopeo--sync--src_type"></a>`src_type`

Data type: `Skopeo::SrcType`

Source transport: `docker`,`dir` or `yaml`. Default is `yaml`

Default value: `'yaml'`

##### <a name="-skopeo--sync--dest"></a>`dest`

Data type: `String`

Destination registry

##### <a name="-skopeo--sync--dest_prefix"></a>`dest_prefix`

Data type: `Optional[String]`

Set prefix for destination registry

Default value: `undef`

##### <a name="-skopeo--sync--dest_type"></a>`dest_type`

Data type: `Skopeo::DestType`

Destination transport, either `docker` or `dir`. Default: `docker`

Default value: `'docker'`

##### <a name="-skopeo--sync--args"></a>`args`

Data type: `Skopeo::Args`

Optional key-value arguments passed to the sync command

Default value: `$skopeo::args`

##### <a name="-skopeo--sync--matrix"></a>`matrix`

Data type: `Optional[Skopeo::Matrix]`

A hash with `images` and `versions` array that will be cross joined

Default value: `undef`

##### <a name="-skopeo--sync--by_tag"></a>`by_tag`

Data type: `Skopeo::ByTag`

Hash containing image name and version (regexp)

Default value: `{}`

##### <a name="-skopeo--sync--tls_verify"></a>`tls_verify`

Data type: `Boolean`

HTTPS TLS verification

Default value: `true`

##### <a name="-skopeo--sync--redirect_logs"></a>`redirect_logs`

Data type: `Boolean`

Whether logs should be redirected to a file stored in the `log_dir`

Default value: `true`

##### <a name="-skopeo--sync--on_change"></a>`on_change`

Data type: `Boolean`

Whether synchronization should be performed upon config change

Default value: `true`

##### <a name="-skopeo--sync--user"></a>`user`

Data type: `String`



Default value: `$skopeo::user`

##### <a name="-skopeo--sync--group"></a>`group`

Data type: `String`



Default value: `$skopeo::group`

##### <a name="-skopeo--sync--base_dir"></a>`base_dir`

Data type: `Stdlib::Unixpath`



Default value: `$skopeo::base_dir`

##### <a name="-skopeo--sync--log_dir"></a>`log_dir`

Data type: `Stdlib::Unixpath`



Default value: `$skopeo::log_dir`

## Data types

### <a name="Skopeo--Args"></a>`Skopeo::Args`

Optional arguments

Alias of `Hash[String[1], Optional[String]]`

### <a name="Skopeo--ByTag"></a>`Skopeo::ByTag`

Images with tag/version specification

Alias of `Hash[String[1], String[1]]`

### <a name="Skopeo--DestType"></a>`Skopeo::DestType`

Source transport type

Alias of `Enum['docker', 'dir']`

### <a name="Skopeo--Matrix"></a>`Skopeo::Matrix`

Configuration images X versions to sync

Alias of

```puppet
Struct[{
  images => Array[String[1]],
  versions => Array[String[1]],
}]
```

### <a name="Skopeo--SrcType"></a>`Skopeo::SrcType`

Source transport type

Alias of `Enum['docker', 'dir', 'yaml']`

### <a name="Skopeo--SyncType"></a>`Skopeo::SyncType`

Configuration of synchronization targets

Alias of

```puppet
Hash[String[1], Struct[{
    src                     => String[1],
    dest                    => String[1],
    Optional[dest_prefix]   => String[1],
    Optional[src_type]      => Skopeo::SrcType,
    Optional[dest_type]     => Skopeo::DestType,
    Optional[matrix]        => Skopeo::Matrix,
    Optional[by_tag]        => Skopeo::ByTag,
    Optional[tls_verify]    => Boolean,
    Optional[redirect_logs] => Boolean,
    Optional[on_change]     => Boolean,
    Optional[user]          => String,
    Optional[group]         => String,
    Optional[base_dir]      => Stdlib::Unixpath,
    Optional[log_dir]       => Stdlib::Unixpath,
    Optional[args]          => Hash[String,String],
  }]]
```

